<?php

/*
Plugin Name: Still BE Image Quality Control
Description: Make sure to control the compression quality (level) for each image size individually. (Available: WordPress 5.3+)
Version:     0.5.0
Author:      Daisuke Yamamoto
Author URI:  https://web.analogstd.com/
License:     GPL2
*/


/**
 * 画像の一括リサイズ時の圧縮率を個別に指定できるようにする
 * 
 * @since 0.5.0 Organized items on the setting page and added explanations. Changed the settings to apply.
 *               Modified: /stillbe-image-quality-control.php, /includes/add-filters.php,
 *                         /includes/class-stillbe-img-quality-ctrl-setting.php,
 *                         /includes/trait-stillbe-image-editor-common.php
 *               Added:/includes/ajax-get-attachment-id.php, /includes/ajax-regenerate-images.php,
 *                     /includes/ajax-reset.php, /includes/apply-filter-settings.php,
 *                     /includes/function-stillbe-iqc-htaccess-webp.php
 *
 * @since 0.4.0 Add a Setting Page & Selected the Editor Changed to Prioritize WebP-enabled Library
 *               Modified: /stillbe-image-quality-control.php
 *               Added: /includes/class-stillbe-img-quality-ctrl-setting.php
 *
 * @since 0.3.1 When Deleting an Attachment, Delete WebP at the Same Time
 *               Modified: /include/add-filter.php
 *
 * @since 0.3.0 Changed WebP Creation Method to 'cwebp' Library
 *               Modified: All files
 *
 * @since 0.2.0 Add Classes that extends the Core Image Editor and Set the Compression Quality
 *              when Creating Resized Images with GD / Imagick
 *               Modified: All files
 *
 * @since 0.1.0 Overwrites the All Resized Images with GD functions after 'wp_generate_attachment_metadata' Hook
 *
 */


// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


// Alt が空の時に Exif を使って自動設定するフラグ
define( 'STILLBE_IQ_AUTOSET_ALT_FROM_EXIF',       false );

// 自動リサイズした画像に圧縮品質を表す suffix を追加するフラグ
define( 'STILLBE_IQ_ENABLE_QUALITY_VALUE_SUFFIX', false );

// インターレース PNG・プログレッシブ JPEG を有効化するフラグ
// ただし、サーバ環境がインターレースに対応している場合に限る
define( 'STILLBE_IQ_ENABLE_INTERLACE',            true  );

// WebP を作成するフラグ
// ただし、サーバ環境が WebP 作成に対応している場合に限る
define( 'STILLBE_IQ_ENABLE_WEBP',                 true  );

// WebP 作成時に cwebp ライブラリを使用するフラグ
define( 'STILLBE_IQ_ENABLE_CWEBP_LIBRARY',        true  );

// PNG / GIF の WebP 作成時に -lossless (or -near_lossless) 圧縮を有効にするフラグ
// ただし、cwebp が有効の場合に限る
define( 'STILLBE_IQ_ENABLE_WEBP_LOSSLESS',        true  );

// PNG / GIF の WebP 作成時に -near_lossless オプションが利用可能な場合に使うフラグ
// ただし、cwebp が有効の場合に限る
define( 'STILLBE_IQ_ENABLE_WEBP_NEAR_LOSSLESS',   false );

// Prefix
define( 'STILLBE_IQ_PREFIX',                      'sb-imgq-' );

// Plugin Base Dir
if( ! defined( 'STILLBE_IQ_BASE_DIR' ) ) {
	define( 'STILLBE_IQ_BASE_DIR', untrailingslashit( __DIR__ ) );
}

// Plugin Base URL
if( ! defined( 'STILLBE_IQ_BASE_URL' ) ) {
	define( 'STILLBE_IQ_BASE_URL', trailingslashit( plugin_dir_url( __FILE__ ) ) );
}




// Load Translate File
if( 'ja' === determine_locale() ) {
	load_textdomain( 'stillbedomain', __DIR__. '/languages/ja.mo' );
} else {
	load_plugin_textdomain( 'stillbe-image-quality-control' );
}




// コアの画像処理系に適応するフィルター
require_once( __DIR__. '/includes/add-filters.php' );

// メタデータ生成時に alt を exif から自動設定する
require_once( __DIR__. '/includes/add-alt-from-exif.php' );


// デフォルトの圧縮品質を返す関数
require_once( __DIR__. '/includes/function-stillbe-get-quality-level-array.php' );


// WebP対応ブラウザではWebPを配信するようにする.htaccessを設定する関数
require_once( __DIR__. '/includes/function-stillbe-iqc-htaccess-webp.php' );


// Image Editor で使用する共通メソッドを定義する
require_once( __DIR__. '/includes/trait-stillbe-image-editor-common.php' );


// GD と Imagick の Class ファイルを読み込む
if( file_exists( ABSPATH. WPINC. '/class-wp-image-editor.php' ) ) {
	require_once( ABSPATH. WPINC. '/class-wp-image-editor.php' );
}
if( file_exists( ABSPATH. WPINC. '/class-wp-image-editor-gd.php' ) ) {
	require_once( ABSPATH. WPINC. '/class-wp-image-editor-gd.php' );
}
if( file_exists( ABSPATH. WPINC. '/class-wp-image-editor-imagick.php' ) ) {
	require_once( ABSPATH. WPINC. '/class-wp-image-editor-imagick.php' );
}


// WP の組込 Class を継承した GD 用エディタ Class
if( class_exists( 'WP_Image_Editor_GD' ) ) {
	require_once( __DIR__. '/includes/class-stillbe-wp-image-editor-gd.php' );
}

// WP の組込 Class を継承した Imagick 用エディタ Class
if( class_exists( 'WP_Image_Editor_Imagick' ) ) {
	require_once( __DIR__. '/includes/class-stillbe-wp-image-editor-imagick.php' );
}


// 有効化の時にWebP置換用のhtaccessを追加する
register_activation_hook( __FILE__, function() {
	if( STILLBE_IQ_ENABLE_WEBP ) {
		_stillbe_iqc_htaccess_webp( null );
	}
} );

// 有効化の時にWebP置換用のhtaccessを削除する
register_deactivation_hook( __FILE__, function() {
	_stillbe_iqc_htaccess_webp( false );
} );


// 設定画面
require_once( __DIR__. '/includes/class-stillbe-img-quality-ctrl-setting.php' );

new StillBE_Img_Quality_Ctrl_Setting();


// 設定を適応するフィルター
require_once( __DIR__. '/includes/apply-filter-settings.php' );


// 画像のID一覧
require_once( __DIR__. '/includes/ajax-get-attachment-id.php' );


// 再生成用
require_once( __DIR__. '/includes/ajax-regenerate-images.php' );


// 設定リセット用
require_once( __DIR__. '/includes/ajax-reset.php' );




// END of the File



